[![PyPI version](https://img.shields.io/pypi/v/stackboost.svg?colorB=4cc61e)](https://pypi.org/project/stackboost/) 
[![PyPI license](https://img.shields.io/pypi/l/stackboost.svg)](https://github.com/leffff/stackboost/blob/main/LICENSE)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/waveml.svg)](https://pypi.python.org/pypi/stackboost/)

# stackboost
Stacked decision trees algorithm

